# MolVis

`MolVis` is a program for molecular structure visualisation, creation, and generation of high quality rendered figures

# Installation

Clone the repository and install using setup.py

```
pip install .
```
